# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/cart/call/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/cart/call/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Cart\\Call\\": "packages/cart/call/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Cart\Call\Providers\CallServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Call'  => Cart\Call\Facades\Call::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Cart\\CallTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Cart\Call\Providers\CallServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Cart\Call\Providers\CallServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Cart\Call\Providers\CallServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/call/{modulename}

**User**

    http://path-to-route-folder/user/call/{modulename}

**Public**

    http://path-to-route-folder/calls


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/call/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/call/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/call/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/call/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/call/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/call/{modulename}/{slug}
    METHOD: GET